==> trilinos_13.2.0.orig.tar.gz: Trilinos-trilinos-release-13-2-0/packages/stk/stk_unit_tests/stk_coupling/UnitTestSplitCommSingleton.cpp <==
// Copyright 2002 - 2008, 2010, 2011 National Technology Engineering
// Solutions of Sandia, LLC (NTESS). Under the terms of Contract
// DE-NA0003525 with NTESS, the U.S. Government retains certain rights
// in this software.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
// 
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
// 
//     * Neither the name of NTESS nor the names of its contributors
//       may be used to endorse or promote products derived from this
//       software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#include <gtest/gtest.h>                // for AssertHelper, ASSERT_TRUE, etc
#include <stk_util/parallel/Parallel.hpp>
#include <stk_coupling/SplitComms.hpp>
#include <stk_coupling/SplitCommsSingleton.hpp>

namespace {

void unset_split_comms_for_testing()
{
  stk::coupling::set_split_comms_singleton(stk::coupling::SplitComms());
}

TEST(UnitTestSplitCommSingleton, get_uninitialized)
{
  unset_split_comms_for_testing();
  const stk::coupling::SplitComms& splitComms = stk::coupling::get_split_comms_singleton();
  EXPECT_FALSE(splitComms.is_initialized());
}

TEST(UnitTestSplitCommSingleton, set_split_comms_singleton)
{
  int color = 0;
  stk::coupling::set_split_comms_singleton(stk::coupling::SplitComms(MPI_COMM_WORLD, color));
  EXPECT_TRUE(stk::coupling::get_split_comms_singleton().is_initialized());
}

}

==> trilinos_16.1.0.orig.tar.gz: Trilinos-trilinos-release-16-1-0/packages/stk/stk_unit_tests/stk_coupling/UnitTestSplitCommSingleton.cpp <==
// Copyright 2002 - 2008, 2010, 2011 National Technology Engineering
// Solutions of Sandia, LLC (NTESS). Under the terms of Contract
// DE-NA0003525 with NTESS, the U.S. Government retains certain rights
// in this software.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
// 
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
// 
//     * Neither the name of NTESS nor the names of its contributors
//       may be used to endorse or promote products derived from this
//       software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#include <gtest/gtest.h>                // for AssertHelper, ASSERT_TRUE, etc
#include <stk_util/parallel/Parallel.hpp>
#include <stk_coupling/SplitComms.hpp>
#include <stk_coupling/SplitCommsSingleton.hpp>

namespace {

void unset_split_comms_for_testing()
{
  stk::coupling::set_split_comms_singleton(stk::coupling::SplitComms());
}

TEST(UnitTestSplitCommSingleton, get_uninitialized)
{
  unset_split_comms_for_testing();
  const stk::coupling::SplitComms& splitComms = stk::coupling::get_split_comms_singleton();
  EXPECT_FALSE(splitComms.is_initialized());
}

TEST(UnitTestSplitCommSingleton, set_split_comms_singleton)
{
  int color = 0;
  stk::coupling::set_split_comms_singleton(stk::coupling::SplitComms(MPI_COMM_WORLD, color));
  EXPECT_TRUE(stk::coupling::get_split_comms_singleton().is_initialized());
}

TEST(UnitTestSplitCommSingleton, split_comms_singleton_free)
{
  int color = 0;
  stk::coupling::set_split_comms_singleton(stk::coupling::SplitComms(MPI_COMM_WORLD, color));
  auto& splitComms = stk::coupling::get_split_comms_singleton();
  splitComms.set_free_comms_in_destructor(true);
  EXPECT_TRUE(splitComms.get_free_comms_in_destructor());
  unset_split_comms_for_testing();  // if MPI doesn't error here, the test passes
}

}
